:py:mod:`piel.models.physical.electronic.defaults`
==================================================

.. py:module:: piel.models.physical.electronic.defaults


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.electronic.defaults.get_default_models



.. py:function:: get_default_models(custom_defaults: dict | None = None) -> dict

   Returns the default models dictionary.

   :param custom_defaults: Custom defaults dictionary.
   :type custom_defaults: dict

   :returns: Default models dictionary.
   :rtype: dict
